@@ -27,7 +27,7 @@ class LessCSS(object):
     """
 
     def __init__(self, media_dir='static', exclude_dirs=None, based=True,
-                compressed=True, output_dir=None):
+                compressed=True, compression='x', output_dir=None):
         """ Initialize LessCSS. When you wrap your web application you need to
         define the following parameters:
 
@@ -50,7 +50,13 @@ class LessCSS(object):
         ``compressed``
             If this is set to `True`, then the compiled CSS file will be
             minimized.
-            
+
+        ``compression``
+            The type of compression to use. Default to standard 'x' compression.
+            Set to 'yui' to use YUI Compressor
+            (http://developer.yahoo.com/yui/compressor/css.html).
+            See "Command-line Usage" at http://lesscss.org/
+
         ``output_dir``
             Define the absolute path of the folder where compiled CSS files
             should be put.
@@ -59,6 +65,7 @@ class LessCSS(object):
         self._media = media_dir
         self._based = based
         self._compressed = compressed
+        self._compression = compression
         self._excluded = exclude_dirs
         self._output = output_dir.rstrip('/') if output_dir else None
         self.compile()
@@ -109,11 +116,13 @@ class LessCSS(object):
         command_opt = ['lessc', '-x']
         if not self._compressed:
             del command_opt[-1]
+        if self._compressed and self._compression.lower() == 'yui':
+            command_opt[1] = '--yui-compress'
         for i in less:
             filename = os.path.splitext(i)[0]
             css = '%s.css' % filename
             if self._output:
-                css = css.split('/')[-1]
+                css = os.path.relpath(css, self._media)
                 css = '%s/%s' % (self._output, css)
             css_time = -1  # Poor man's Integer.MIN_VALUE
             if os.path.isfile(css):
@@ -122,13 +131,17 @@ class LessCSS(object):
             if less_time >= css_time:
                 command_opt.append(i)
                 command_opt.append(css)
+                css_dir = os.path.dirname(css)
+                if not os.path.exists(css_dir):
+                    os.makedirs(css_dir)
                 subprocess.call(command_opt, shell=False)
                 if self._based:
                     del command_opt[-1]
                     css_based = '%s-%s.css' % (filename,
                                                 LessCSS.to60(uuid4().time_low))
                     if self._output:
-                        css_based = css_based.split('/')[-1]
+                        css_based = os.path.relpath(css_based, self._media)
                         css_based = '%s/%s' % (self._output, css_based)
                     command_opt.append(css_based)
                     subprocess.call(command_opt, shell=False)
+            del command_opt[-2:]
